durtools.duration_tokens_to_duration_pairs_with_least_common_denominator
========================================================================

.. autofunction:: abjad.tools.durtools.duration_tokens_to_duration_pairs_with_least_common_denominator
